@@ -2,11 +2,12 @@ __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
 import base64
+import time
+from pathlib import Path
+from typing import Dict, Union, List
 
 from .. import __binary_delimiter__
-from ..helper import yaml
-from pkg_resources import resource_stream
-from typing import Dict, Union, List
+from ..logging import JinaLogger
 
 
 def _encode(clear, key=__binary_delimiter__.decode()):
@@ -28,7 +29,6 @@ def _decode(enc, key=__binary_delimiter__.decode()):
     return ''.join(dec)
 
 
-
 def handle_dot_in_keys(document: Dict[str, Union[Dict, List]]) -> Union[Dict, List]:
     updated_document = {}
     for key, value in document.items():
@@ -38,3 +38,31 @@ def handle_dot_in_keys(document: Dict[str, Union[Dict, List]]) -> Union[Dict, Li
             value[0] = handle_dot_in_keys(value[0])
         updated_document[key.replace('.', '_')] = value
     return updated_document
+
+
+def credentials_file():
+    Path.home().joinpath('.jina').mkdir(parents=True, exist_ok=True)
+    return Path.home().joinpath('.jina').joinpath('access.yml')
+
+
+class Waiter:
+    def __init__(self, seconds, message=''):
+        self.logger = JinaLogger(self.__class__.__name__)
+        self._seconds = seconds
+        self._message = message
+
+    def __enter__(self):
+        self.logger.info(f'waiting for {self._seconds} seconds {self._message}')
+        self._wait_until = time.time() + self._seconds
+        return self
+
+    @property
+    def is_time_up(self):
+        return time.time() > self._wait_until
+
+    def sleep(self, seconds=5):
+        self.logger.debug(f'sleeping for {seconds} seconds')
+        time.sleep(seconds)
+
+    def __exit__(self, type, value, traceback):
+        self.logger.debug(f'took {self._seconds} seconds!')
