@@ -64,11 +64,11 @@ class TirgMultiModalEncoder(TorchDevice, BaseMultiModalEncoder):
 
         return self.model.compose_img_text_features(img_features, text_features)
 
-    @batching_multi_input
+    @batching_multi_input(num_data=2)
     @as_ndarray
     def encode(self, *data: 'np.ndarray', **kwargs) -> 'np.ndarray':
         feature = self._get_features(data).detach()
         if self.on_gpu:
             feature = feature.cpu()
         feature = feature.numpy()
-        return feature
\ No newline at end of file
+        return feature
